@@ -1,36 +1,43 @@
+from __future__ import annotations
+
 import ast
-import inspect
 import logging
 import operator
 import re
 import time
+from collections.abc import Callable, Iterable, Mapping
+from contextlib import suppress
 from functools import partial
 from http.cookiejar import Cookie
-from typing import (
-    Any,
-    Callable,
-    ClassVar,
-    Dict,
-    List,
-    Match,
-    NamedTuple,
-    Optional,
-    Pattern,
-    Sequence,
-    TYPE_CHECKING,
-    Type,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, ClassVar, List, Literal, NamedTuple, Type, TypeVar, Union
 
 import requests.cookies
 
+import streamlink.utils.args
+import streamlink.utils.times
 from streamlink.cache import Cache
 from streamlink.exceptions import FatalPluginError, NoStreamsError, PluginError
 from streamlink.options import Argument, Arguments, Options
 from streamlink.user_input import UserInputRequester
 
+
 if TYPE_CHECKING:  # pragma: no cover
-    from streamlink.session import Streamlink
+    from streamlink.session.session import Streamlink
+
+
+#: See the :func:`~.pluginargument` decorator
+_PLUGINARGUMENT_TYPE_REGISTRY: Mapping[str, Callable[[Any], Any]] = {
+    "int": int,
+    "float": float,
+    "bool": streamlink.utils.args.boolean,
+    "comma_list": streamlink.utils.args.comma_list,
+    "comma_list_filter": streamlink.utils.args.comma_list_filter,
+    "filesize": streamlink.utils.args.filesize,
+    "keyvalue": streamlink.utils.args.keyvalue,
+    "num": streamlink.utils.args.num,
+    "hours_minutes_seconds": streamlink.utils.times.hours_minutes_seconds,
+    "hours_minutes_seconds_float": streamlink.utils.times.hours_minutes_seconds_float,
+}
 
 
 log = logging.getLogger(__name__)
@@ -42,7 +49,7 @@ BIT_RATE_WEIGHT_RATIO = 2.8
 
 ALT_WEIGHT_MOD = 0.01
 
-QUALITY_WEIGTHS_EXTRA = {
+QUALITY_WEIGHTS_EXTRA = {
     "other": {
         "live": 1080,
     },
@@ -71,12 +78,24 @@ NORMAL_PRIORITY = 20
 LOW_PRIORITY = 10
 NO_PRIORITY = 0
 
-_COOKIE_KEYS = \
-    "version", "name", "value", "port", "domain", "path", "secure", "expires", "discard", "comment", "comment_url", "rfc2109"
+_COOKIE_KEYS = (
+    "version",
+    "name",
+    "value",
+    "port",
+    "domain",
+    "path",
+    "secure",
+    "expires",
+    "discard",
+    "comment",
+    "comment_url",
+    "rfc2109",
+)
 
 
 def stream_weight(stream):
-    for group, weights in QUALITY_WEIGTHS_EXTRA.items():
+    for group, weights in QUALITY_WEIGHTS_EXTRA.items():
         if stream in weights:
             return weights[stream], group
 
@@ -119,9 +138,9 @@ def iterate_streams(streams):
     for name, stream in streams:
         if isinstance(stream, list):
             for sub_stream in stream:
-                yield (name, sub_stream)
+                yield name, sub_stream
         else:
-            yield (name, stream)
+            yield name, stream
 
 
 def stream_type_priority(stream_types, stream):
@@ -159,37 +178,58 @@ def stream_sorting_filter(expr, stream_weight):
     return func
 
 
-def parse_params(params: Optional[str] = None) -> Dict[str, Any]:
-    rval: Dict[str, Any] = {}
+def parse_params(params: str | None = None) -> dict[str, Any]:
+    rval: dict[str, Any] = {}
     if not params:
         return rval
 
     matches = re.findall(PARAMS_REGEX, params)
 
     for key, value in matches:
-        try:
+        with suppress(Exception):
             value = ast.literal_eval(value)
-        except Exception:
-            pass
-
         rval[key] = value
 
     return rval
 
 
 class Matcher(NamedTuple):
-    pattern: Pattern
+    pattern: re.Pattern
     priority: int
+    name: str | None = None
 
 
-# Add front- and back-wrappers to the deprecated plugin's method resolution order (see Plugin.__new__)
-class PluginWrapperMeta(type):
-    def mro(cls):
-        # cls.__base__ is the PluginWrapperFront which is based on the deprecated plugin class
-        mro = list(cls.__base__.__mro__)
-        # cls is the PluginWrapperBack and needs to be inserted after the deprecated plugin class
-        mro.insert(2, cls)
-        return mro
+MType = TypeVar("MType")
+
+
+class _MCollection(List[MType]):
+    def __init__(self, **kwargs) -> None:
+        super().__init__(**kwargs)
+        self._names: dict[str, MType] = {}
+
+    def __getitem__(self, item):
+        return self._names[item] if isinstance(item, str) else super().__getitem__(item)
+
+
+class Matchers(_MCollection[Matcher]):
+    def register(self, matcher: Matcher) -> None:
+        super().insert(0, matcher)
+        if matcher.name:
+            if matcher.name in self._names:
+                raise ValueError(f"A matcher named '{matcher.name}' has already been registered")
+            self._names[matcher.name] = matcher
+
+
+class Matches(_MCollection[Union[re.Match, None]]):
+    def update(self, matchers: Matchers, value: str) -> tuple[re.Pattern | None, re.Match | None]:
+        matches = [(matcher, matcher.pattern.match(value)) for matcher in matchers]
+
+        self.clear()
+        self.extend(match for matcher, match in matches)
+        self._names.clear()
+        self._names.update((matcher.name, match) for matcher, match in matches if matcher.name)
+
+        return next(((matcher.pattern, match) for matcher, match in matches if match is not None), (None, None))
 
 
 class Plugin:
@@ -197,97 +237,66 @@ class Plugin:
     Plugin base class for retrieving streams and metadata from the URL specified.
     """
 
-    matchers: ClassVar[Optional[List[Matcher]]] = None
-    """
-    The list of plugin matchers (URL pattern + priority).
+    #: The Streamlink session which this plugin instance belongs to,
+    #: with access to its :attr:`HTTPSession <streamlink.session.Streamlink.http>`.
+    session: Streamlink
 
-    Use the :func:`pluginmatcher` decorator to initialize this list.
-    """
+    #: Plugin options, initialized with the user-set values of the plugin's arguments.
+    options: Options
 
-    arguments: ClassVar[Optional[Arguments]] = None
-    """
-    The plugin's :class:`Arguments <streamlink.options.Arguments>` collection.
+    #: Plugin cache object, used to store plugin-specific data other than HTTP session cookies.
+    cache: Cache
 
-    Use the :func:`pluginargument` decorator to initialize this collection.
-    """
+    #: The list of plugin matchers (URL pattern + priority + optional name).
+    #: Supports matcher lookups by the matcher index or the optional matcher name.
+    #:
+    #: Use the :func:`pluginmatcher` decorator to initialize plugin matchers.
+    matchers: ClassVar[Matchers | None] = None
 
-    matches: Sequence[Optional[Match]]
-    """A tuple of :class:`re.Match` results of all defined matchers"""
+    #: The plugin's :class:`Arguments <streamlink.options.Arguments>` collection.
+    #:
+    #: Use the :func:`pluginargument` decorator to initialize plugin arguments.
+    arguments: ClassVar[Arguments | None] = None
 
-    matcher: Optional[Pattern]
-    """A reference to the compiled :class:`re.Pattern` of the first matching matcher"""
+    #: A list of optional :class:`re.Match` results of all defined matchers.
+    #: Supports match lookups by the matcher index or the optional matcher name.
+    matches: Matches
 
-    match: Optional[Match]
-    """A reference to the :class:`re.Match` result of the first matching matcher"""
+    #: A reference to the compiled :class:`re.Pattern` of the first matching matcher.
+    matcher: re.Pattern | None = None
 
-    # plugin metadata attributes
-    id: Optional[str] = None
-    """Metadata 'id' attribute: unique stream ID, etc."""
-    title: Optional[str] = None
-    """Metadata 'title' attribute: the stream's short descriptive title"""
-    author: Optional[str] = None
-    """Metadata 'author' attribute: the channel or broadcaster name, etc."""
-    category: Optional[str] = None
-    """Metadata 'category' attribute: name of a game being played, a music genre, etc."""
+    #: A reference to the :class:`re.Match` result of the first matching matcher.
+    match: re.Match | None = None
+
+    #: Metadata 'id' attribute: unique stream ID, etc.
+    id: str | None = None
+    #: Metadata 'title' attribute: the stream's short descriptive title.
+    title: str | None = None
+    #: Metadata 'author' attribute: the channel or broadcaster name, etc.
+    author: str | None = None
+    #: Metadata 'category' attribute: name of a game being played, a music genre, etc.
+    category: str | None = None
 
-    options = Options()
     _url: str = ""
 
-    # deprecated
-    can_handle_url: Callable[[str], bool]
-    # deprecated
-    priority: Callable[[str], int]
-
-    # Handle deprecated plugin constructors which only take the url argument
-    def __new__(cls, *args, **kwargs):
-        # Ignore plugins without custom constructors or wrappers
-        if cls.__init__ is Plugin.__init__ or hasattr(cls, "_IS_DEPRECATED_PLUGIN_WRAPPER"):
-            return super().__new__(cls)
-
-        # Ignore custom constructors which have a formal "session" parameter or a variable positional parameter
-        sig = inspect.signature(cls.__init__).parameters
-        if "session" in sig or any(param.kind == inspect.Parameter.VAR_POSITIONAL for param in sig.values()):
-            return super().__new__(cls)
-
-        # Wrapper class which overrides the very first constructor in the MRO
-        # noinspection PyAbstractClass
-        class PluginWrapperFront(cls):
-            _IS_DEPRECATED_PLUGIN_WRAPPER = True
-
-            # The __module__ value needs to be copied
-            __module__ = cls.__module__
-
-            def __init__(self, session, url):
-                # Take any arguments, but only pass the URL to the custom constructor of the deprecated plugin
-                # noinspection PyArgumentList
-                super().__init__(url)
-                log.warning(f"Initialized {self.module} plugin with deprecated constructor")
-
-        # Wrapper class which comes after the deprecated plugin in the MRO
-        # noinspection PyAbstractClass
-        class PluginWrapperBack(PluginWrapperFront, metaclass=PluginWrapperMeta):
-            def __init__(self, *_, **__):
-                # Take any arguments from the super() call of the constructor of the deprecated plugin,
-                # but pass the right args and keywords to the Plugin constructor
-                super().__init__(*args, **kwargs)
-
-        return cls.__new__(PluginWrapperBack, *args, **kwargs)
-
-    def __init__(self, session: "Streamlink", url: str):
+    def __init__(self, session: Streamlink, url: str, options: Options | None = None):
         """
         :param session: The Streamlink session instance
         :param url: The input URL used for finding and resolving streams
+        :param options: An optional :class:`Options` instance
         """
 
         modulename = self.__class__.__module__
         self.module = modulename.split(".")[-1]
         self.logger = logging.getLogger(modulename)
+        self.options = Options() if options is None else options
         self.cache = Cache(
             filename="plugin-cache.json",
             key_prefix=self.module,
         )
 
-        self.session: "Streamlink" = session
+        self.session: Streamlink = session
+        self.matches = Matches()
         self.url: str = url
 
         self.load_cookies()
@@ -305,21 +314,18 @@ class Plugin:
     def url(self, value: str):
         self._url = value
 
-        matches = [(pattern, pattern.match(value)) for pattern, priority in self.matchers or []]
-        self.matches = tuple(m for p, m in matches)
-        self.matcher, self.match = next(((p, m) for p, m in matches if m is not None), (None, None))
+        if self.matchers:
+            self.matcher, self.match = self.matches.update(self.matchers, value)
 
-    @classmethod
-    def set_option(cls, key, value):
-        cls.options.set(key, value)
+    def set_option(self, key, value):
+        self.options.set(key, value)
 
-    @classmethod
-    def get_option(cls, key):
-        return cls.options.get(key)
+    def get_option(self, key):
+        return self.options.get(key)
 
     @classmethod
     def get_argument(cls, key):
-        return cls.arguments.get(key)
+        return cls.arguments and cls.arguments.get(key)
 
     @classmethod
     def stream_weight(cls, stream):
@@ -329,7 +335,7 @@ class Plugin:
     def default_stream_types(cls, streams):
         stream_types = ["hls", "http"]
 
-        for name, stream in iterate_streams(streams):
+        for _name, stream in iterate_streams(streams):
             stream_type = type(stream).shortname()
 
             if stream_type not in stream_types:
@@ -337,31 +343,13 @@ class Plugin:
 
         return stream_types
 
-    @classmethod
-    def broken(cls, issue=None):
-        def func(*args, **kwargs):
-            msg = (
-                "This plugin has been marked as broken. This is likely due to "
-                "changes to the service preventing a working implementation. "
-            )
-
-            if issue:
-                msg += "More info: https://github.com/streamlink/streamlink/issues/{0}".format(issue)
-
-            raise PluginError(msg)
-
-        def decorator(*args, **kwargs):
-            return func
-
-        return decorator
-
     def streams(self, stream_types=None, sorting_excludes=None):
         """
         Attempts to extract available streams.
 
         Returns a :class:`dict` containing the streams, where the key is
         the name of the stream (most commonly the quality name), with the value
-        being a :class:`Stream` instance.
+        being a :class:`Stream <streamlink.stream.Stream>` instance.
 
         The result can contain the synonyms **best** and **worst** which
         point to the streams which are likely to be of highest and
@@ -387,7 +375,7 @@ class Plugin:
 
         :param stream_types: A list of stream types to return
         :param sorting_excludes: Specify which streams to exclude from the best/worst synonyms
-        :returns: A :class:`dict` of stream names and :class:`streamlink.stream.Stream` instances
+        :returns: A :class:`dict` of stream names and :class:`Stream <streamlink.stream.Stream>` instances
         """
 
         try:
@@ -401,7 +389,7 @@ class Plugin:
         except NoStreamsError:
             return {}
         except (OSError, ValueError) as err:
-            raise PluginError(err)
+            raise PluginError(err) from err
 
         if not ostreams:
             return {}
@@ -410,9 +398,7 @@ class Plugin:
             stream_types = self.default_stream_types(ostreams)
 
         # Add streams depending on stream type and priorities
-        sorted_streams = sorted(iterate_streams(ostreams),
-                                key=partial(stream_type_priority,
-                                            stream_types))
+        sorted_streams = sorted(iterate_streams(ostreams), key=partial(stream_type_priority, stream_types))
 
         streams = {}
         for name, stream in sorted_streams:
@@ -424,7 +410,7 @@ class Plugin:
 
             # drop _alt from any stream names
             if name.endswith("_alt"):
-                name = name[:-len("_alt")]
+                name = name[: -len("_alt")]
 
             existing = streams.get(name)
             if existing:
@@ -455,7 +441,7 @@ class Plugin:
 
         # Create the best/worst synonyms
         def stream_weight_only(s):
-            return (self.stream_weight(s)[0] or (len(streams) == 1 and 1))
+            return self.stream_weight(s)[0] or (len(streams) == 1 and 1)
 
         stream_names = filter(stream_weight_only, streams.keys())
         sorted_streams = sorted(stream_names, key=stream_weight_only)
@@ -490,37 +476,38 @@ class Plugin:
         """
         Implement the stream and metadata retrieval here.
 
-        Needs to return either a dict of :class:`streamlink.stream.Stream` instances mapped by stream name, or needs to act
-        as a generator which yields tuples of stream names and :class:`streamlink.stream.Stream` instances.
+        Needs to return either a dict of :class:`Stream <streamlink.stream.Stream>` instances mapped by stream name,
+        or needs to act as a generator which yields tuples of stream names and :class:`Stream <streamlink.stream.Stream>`
+        instances.
         """
 
         raise NotImplementedError
 
-    def get_metadata(self) -> Dict[str, Optional[str]]:
+    def get_metadata(self) -> Mapping[str, str | None]:
         return dict(
             id=self.get_id(),
             author=self.get_author(),
             category=self.get_category(),
-            title=self.get_title()
+            title=self.get_title(),
         )
 
-    def get_id(self) -> Optional[str]:
+    def get_id(self) -> str | None:
         return None if self.id is None else str(self.id).strip()
 
-    def get_title(self) -> Optional[str]:
+    def get_title(self) -> str | None:
         return None if self.title is None else str(self.title).strip()
 
-    def get_author(self) -> Optional[str]:
+    def get_author(self) -> str | None:
         return None if self.author is None else str(self.author).strip()
 
-    def get_category(self) -> Optional[str]:
+    def get_category(self) -> str | None:
         return None if self.category is None else str(self.category).strip()
 
     def save_cookies(
         self,
-        cookie_filter: Optional[Callable[[Cookie], bool]] = None,
+        cookie_filter: Callable[[Cookie], bool] | None = None,
         default_expires: int = 60 * 60 * 24 * 7,
-    ) -> List[str]:
+    ) -> list[str]:
         """
         Store the cookies from :attr:`session.http` in the plugin cache until they expire. The cookies can be filtered
         by supplying a filter method. e.g. ``lambda c: "auth" in c.name``. If no expiry date is given in the
@@ -557,7 +544,7 @@ class Plugin:
 
         return saved
 
-    def load_cookies(self) -> List[str]:
+    def load_cookies(self) -> list[str]:
         """
         Load any stored cookies for the plugin that have not expired.
 
@@ -577,10 +564,10 @@ class Plugin:
 
         return restored
 
-    def clear_cookies(self, cookie_filter: Optional[Callable] = None) -> List[str]:
+    def clear_cookies(self, cookie_filter: Callable[[Cookie], bool] | None = None) -> list[str]:
         """
         Removes all saved cookies for this plugin. To filter the cookies that are deleted
-        specify the ``cookie_filter`` argument (see :func:`save_cookies`).
+        specify the ``cookie_filter`` argument (see :meth:`save_cookies`).
 
         :param cookie_filter: a function to filter the cookies
         :type cookie_filter: function
@@ -601,39 +588,43 @@ class Plugin:
         return removed
 
     def input_ask(self, prompt: str) -> str:
-        user_input_requester: Optional[UserInputRequester] = self.session.get_option("user-input-requester")
+        user_input_requester: UserInputRequester | None = self.session.get_option("user-input-requester")
         if user_input_requester:
             try:
                 return user_input_requester.ask(prompt)
             except OSError as err:
-                raise FatalPluginError(f"User input error: {err}")
+                raise FatalPluginError(f"User input error: {err}") from err
         raise FatalPluginError("This plugin requires user input, however it is not supported on this platform")
 
     def input_ask_password(self, prompt: str) -> str:
-        user_input_requester: Optional[UserInputRequester] = self.session.get_option("user-input-requester")
+        user_input_requester: UserInputRequester | None = self.session.get_option("user-input-requester")
         if user_input_requester:
             try:
                 return user_input_requester.ask_password(prompt)
             except OSError as err:
-                raise FatalPluginError(f"User input error: {err}")
+                raise FatalPluginError(f"User input error: {err}") from err
         raise FatalPluginError("This plugin requires user input, however it is not supported on this platform")
 
 
 def pluginmatcher(
-    pattern: Pattern,
+    pattern: re.Pattern,
     priority: int = NORMAL_PRIORITY,
-) -> Callable[[Type[Plugin]], Type[Plugin]]:
+    name: str | None = None,
+) -> Callable[[type[Plugin]], type[Plugin]]:
     """
     Decorator for plugin URL matchers.
 
-    A matcher consists of a compiled regular expression pattern for the plugin's input URL and a priority value.
+    A matcher consists of a compiled regular expression pattern for the plugin's input URL,
+    a priority value and an optional name.
     The priority value determines which plugin gets chosen by
-    :meth:`Streamlink.resolve_url <streamlink.Streamlink.resolve_url>` if multiple plugins match the input URL.
+    :meth:`Streamlink.resolve_url() <streamlink.session.Streamlink.resolve_url>` if multiple plugins match the input URL.
+    The matcher name can be used for accessing it and its matching result when multiple matchers are defined.
 
     Plugins must at least have one matcher. If multiple matchers are defined, then the first matching one
     according to the order of which they have been defined (top to bottom) will be responsible for setting the
     :attr:`Plugin.matcher` and :attr:`Plugin.match` attributes on the :class:`Plugin` instance.
-    The :attr:`Plugin.matchers` and :attr:`Plugin.matches` attributes are affected by all defined matchers.
+    The :attr:`Plugin.matchers` and :attr:`Plugin.matches` attributes are affected by all defined matchers,
+    and both support referencing matchers and matches by matcher index and name.
 
     .. code-block:: python
 
@@ -655,33 +646,53 @@ def pluginmatcher(
             ...
     """
 
-    matcher = Matcher(pattern, priority)
+    matcher = Matcher(pattern, priority, name)
 
-    def decorator(cls: Type[Plugin]) -> Type[Plugin]:
+    def decorator(cls: type[Plugin]) -> type[Plugin]:
         if not issubclass(cls, Plugin):
-            raise TypeError(f"{repr(cls)} is not a Plugin")
+            raise TypeError(f"{cls.__name__} is not a Plugin")
         if cls.matchers is None:
-            cls.matchers = []
-        cls.matchers.insert(0, matcher)
+            cls.matchers = Matchers()
+        cls.matchers.register(matcher)
 
         return cls
 
     return decorator
 
 
+_TChoices = TypeVar("_TChoices", bound=Iterable)
+
+
+# noinspection GrazieInspection,PyShadowingBuiltins
 def pluginargument(
     name: str,
+    action: str | None = None,
+    nargs: int | Literal["?", "*", "+"] | None = None,
+    const: Any = None,
+    default: Any = None,
+    type: str | Callable[[Any], _TChoices | Any] | None = None,  # noqa: A002
+    type_args: list | tuple | None = None,
+    type_kwargs: Mapping[str, Any] | None = None,
+    choices: _TChoices | None = None,
     required: bool = False,
-    requires: Optional[Union[str, Sequence[str]]] = None,
-    prompt: Optional[str] = None,
+    help: str | None = None,  # noqa: A002
+    metavar: str | list[str] | tuple[str, ...] | None = None,
+    dest: str | None = None,
+    requires: str | list[str] | tuple[str, ...] | None = None,
+    prompt: str | None = None,
     sensitive: bool = False,
-    argument_name: Optional[str] = None,
-    dest: Optional[str] = None,
-    is_global: bool = False,
-    **options,
-) -> Callable[[Type[Plugin]], Type[Plugin]]:
+    argument_name: str | None = None,
+) -> Callable[[type[Plugin]], type[Plugin]]:
     """
-    Decorator for plugin arguments. Takes the same arguments as :class:`streamlink.options.Argument`.
+    Decorator for plugin arguments. Takes the same arguments as :class:`Argument <streamlink.options.Argument>`.
+
+    One exception is the ``type`` argument, which also accepts a ``str`` value:
+
+    Plugins built into Streamlink **must** reference the used argument-type function by name, so the pluginargument data
+    can be JSON-serialized. ``type_args`` and ``type_kwargs`` can be used to parametrize the type-argument function,
+    but their values **must** only consist of literal objects.
+
+    The available functions are defined in the :data:`~._PLUGINARGUMENT_TYPE_REGISTRY`.
 
     .. code-block:: python
 
@@ -707,21 +718,37 @@ def pluginargument(
     assuming the plugin's module name is ``myplugin``.
     """
 
+    _type: Callable[[Any], _TChoices] | None
+    if not isinstance(type, str):
+        _type = type
+    else:
+        if type not in _PLUGINARGUMENT_TYPE_REGISTRY:
+            raise TypeError(f"Invalid pluginargument type {type}")
+        _type = _PLUGINARGUMENT_TYPE_REGISTRY[type]
+        if type_args is not None or type_kwargs is not None:
+            _type = _type(*(type_args or ()), **(type_kwargs or {}))
+
     arg = Argument(
-        name,
+        name=name,
+        action=action,
+        nargs=nargs,
+        const=const,
+        default=default,
+        type=_type,
+        choices=choices,
         required=required,
+        help=help,
+        metavar=metavar,
+        dest=dest,
         requires=requires,
         prompt=prompt,
         sensitive=sensitive,
         argument_name=argument_name,
-        dest=dest,
-        is_global=is_global,
-        **options,
     )
 
     def decorator(cls: Type[Plugin]) -> Type[Plugin]:
         if not issubclass(cls, Plugin):
-            raise TypeError(f"{repr(cls)} is not a Plugin")
+            raise TypeError(f"{repr(cls)} is not a Plugin")  # noqa: RUF010  # builtins.repr gets monkeypatched in tests
         if cls.arguments is None:
             cls.arguments = Arguments()
         cls.arguments.add(arg)
@@ -732,8 +759,12 @@ def pluginargument(
 
 
 __all__ = [
-    "HIGH_PRIORITY", "NORMAL_PRIORITY", "LOW_PRIORITY", "NO_PRIORITY",
+    "HIGH_PRIORITY",
+    "NORMAL_PRIORITY",
+    "LOW_PRIORITY",
+    "NO_PRIORITY",
     "Plugin",
-    "Matcher", "pluginmatcher",
+    "Matcher",
+    "pluginmatcher",
     "pluginargument",
 ]
